@@ -23,7 +23,6 @@
 #include <stdlib.h>
 
 #include <govirt/govirt.h>
-#include "govirt/glib-compat.h"
 
 static GMainLoop *main_loop;
 
@@ -294,8 +293,6 @@ static gboolean start(gpointer user_data)
 
 int main(int argc, char **argv)
 {
-    g_type_init();
-
     if (argc != 3) {
         g_print("Usage: %s URI VM-NAME\n", argv[0]);
         exit(1);
