@@ -23,7 +23,6 @@
 #include <stdlib.h>
 
 #include <govirt/govirt.h>
-#include "govirt/glib-compat.h"
 
 static GMainLoop *main_loop;
 
@@ -189,7 +188,6 @@ static gboolean start(gpointer user_data)
 int main(int argc, char **argv)
 {
     AsyncData *data;
-    g_type_init();
 
     if (argc != 2) {
         g_print("Usage: %s URI\n", argv[0]);
